Dropped<T> class
final
A result produced when an action was not admitted by the guard.
- Inheritance
-
- Object
- GuardResult<
T> - Dropped
Constructors
- Dropped(DropReason reason)
-
Creates a dropped result with
reason.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- reason → DropReason
-
Why the action was not executed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited